@@ -5,16 +5,16 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-imagebuilder",
-    "1.63.0",
+    "1.64.0",
     __name__[0:-6],
-    "aws-imagebuilder@1.63.0.jsii.tgz",
+    "aws-imagebuilder@1.64.0.jsii.tgz",
 )
 
 __all__ = [
